@@ -1,7 +1,7 @@
 // main.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2006, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -13,9 +13,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 *****************************************************************************/
 
@@ -66,13 +66,23 @@ int main ( int argc, char **argv )
         }
     }
 
-    // Construct the main form, and show it to the world.
-    qjackctlMainForm w;
+	// What style do we create these forms?
+	Qt::WFlags wflags = Qt::WStyle_Customize
+		| Qt::WStyle_Title
+		| Qt::WStyle_SysMenu
+		| Qt::WStyle_MinMax
+		| Qt::WType_TopLevel;
+	if (settings.bKeepOnTop)
+		wflags |= Qt::WStyle_Tool;
+	// Construct the main form, and show it to the world.
+	qjackctlMainForm w(0, 0, wflags);
 	app.setMainWidget(&w);
     w.setup(&settings);
     // If we have a systray icon, we'll skip this.
-    if (!settings.bSystemTray)
+    if (!settings.bSystemTray) {
         w.show();
+        w.adjustSize();
+    }
 
     // Register the quit signal/slot.
     // app.connect(&app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()));
