@@ -1,7 +1,7 @@
 // qjackctlAbout.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2005, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2006, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -13,9 +13,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 *****************************************************************************/
 
@@ -27,12 +27,13 @@
 #define QJACKCTL_TITLE      PACKAGE_NAME
 #define QJACKCTL_VERSION    PACKAGE_VERSION
 
-#define QJACKCTL_SUBTITLE1  "JACK Audio Connection Kit"
+#define QJACKCTL_SUBTITLE0  "JACK"
+#define QJACKCTL_SUBTITLE1  QJACKCTL_SUBTITLE0 " Audio Connection Kit"
 #define QJACKCTL_SUBTITLE2  "Qt GUI Interface"
 
 #define QJACKCTL_SUBTITLE   QJACKCTL_SUBTITLE1 " - " QJACKCTL_SUBTITLE2
 #define QJACKCTL_WEBSITE    "http://qjackctl.sourceforge.net"
-#define QJACKCTL_COPYRIGHT  "Copyright (C) 2003-2005, rncbc aka Rui Nuno Capela. All rights reserved."
+#define QJACKCTL_COPYRIGHT  "Copyright (C) 2003-2006, rncbc aka Rui Nuno Capela. All rights reserved."
 
 #endif  // __qjackctlAbout_h
 
