@@ -14,9 +14,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 *****************************************************************************/
 
@@ -25,10 +25,12 @@
 
 #include "qjackctlPatchbayFile.h"
 
+#include <qsocketnotifier.h>
 #include <qapplication.h>
 #include <qobjectlist.h>
 #include <qeventloop.h>
 #include <qmessagebox.h>
+#include <qprocess.h>
 #include <qregexp.h>
 #include <qtimer.h>
 
@@ -64,7 +66,13 @@
 #define QJACKCTL_FDREAD         0
 #define QJACKCTL_FDWRITE        1
 
+#if !defined(WIN32)
+#include <unistd.h>
 static int g_fdStdout[2] = { QJACKCTL_FDNIL, QJACKCTL_FDNIL };
+#else
+#include <io.h>
+#include <process.h>
+#endif
 
 // Custom event types.
 #define QJACKCTL_PORT_EVENT     1000
@@ -131,6 +139,9 @@ void qjackctlMainForm::init (void)
 // Kind of destructor.
 void qjackctlMainForm::destroy (void)
 {
+	if (m_bJackDetach)
+		m_bJackSurvive = true;
+
     // Stop server, if not already...
     stopJackServer();
 
@@ -170,11 +181,16 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
     // To avoid any background flickering,
     // we'll hide the main display.
     StatusDisplayFrame->hide();
+	updateButtons();
 
     // What style do we create these forms?
-    WFlags wflags = Qt::WType_TopLevel;
-    if (m_pSetup->bKeepOnTop)
-        wflags |= Qt::WStyle_Tool;
+	WFlags wflags = Qt::WStyle_Customize
+		| Qt::WStyle_Title
+		| Qt::WStyle_SysMenu
+		| Qt::WStyle_MinMax
+		| Qt::WType_TopLevel;
+	if (m_pSetup->bKeepOnTop)
+		wflags |= Qt::WStyle_Tool;
     // All forms are to be created right now.
     m_pMessagesForm    = new qjackctlMessagesForm    (this, 0, wflags);
     m_pStatusForm      = new qjackctlStatusForm      (this, 0, wflags);
@@ -217,13 +233,14 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
     resetXrunStats();
 
     // Check if we can redirect our own stdout/stderr...
+#if !defined(WIN32)
     if (m_pSetup->bStdoutCapture && ::pipe(g_fdStdout) == 0) {
         ::dup2(g_fdStdout[QJACKCTL_FDWRITE], STDOUT_FILENO);
         ::dup2(g_fdStdout[QJACKCTL_FDWRITE], STDERR_FILENO);
         m_pStdoutNotifier = new QSocketNotifier(g_fdStdout[QJACKCTL_FDREAD], QSocketNotifier::Read, this);
         QObject::connect(m_pStdoutNotifier, SIGNAL(activated(int)), this, SLOT(stdoutNotifySlot(int)));
     }
-    
+#endif
 #ifdef CONFIG_ALSA_SEQ
     // Start our ALSA sequencer interface.
     if (snd_seq_open(&m_pAlsaSeq, "hw", SND_SEQ_OPEN_DUPLEX, 0) < 0)
@@ -269,7 +286,7 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
     if (m_pPatchbayForm) {
 		m_pPatchbayForm->setRecentPatchbays(m_pSetup->patchbays);
 	 	if (!m_pSetup->sPatchbayPath.isEmpty())
-        	m_pPatchbayForm->loadPatchbayFile(m_pSetup->sPatchbayPath);
+			m_pPatchbayForm->loadPatchbayFile(m_pSetup->sPatchbayPath);
 	}
 	
     // Try to find if we can start in detached mode (client-only)
@@ -299,7 +316,8 @@ bool qjackctlMainForm::queryClose (void)
 #ifdef CONFIG_SYSTEM_TRAY
     // If we're not quitting explicitly and there's an
     // active system tray icon, then just hide ourselves.
-    if (!m_bQuitForce && isVisible() && m_pSetup->bSystemTray && m_pSystemTray) {
+	if (!m_bQuitForce && isVisible()
+		&& m_pSetup->bSystemTray && m_pSystemTray && m_pJackClient) {
         m_pSetup->saveWidgetGeometry(this);
         hide();
         bQueryClose = false;
@@ -307,7 +325,8 @@ bool qjackctlMainForm::queryClose (void)
 #endif
 
     // Check if JACK daemon is currently running...
-    if (bQueryClose && m_pJack && m_pJack->isRunning() && m_pSetup->bQueryClose) {
+	if (bQueryClose && m_pJack && m_pJack->isRunning()
+		&& (m_pSetup->bQueryClose || m_pSetup->bQueryShutdown)) {
         switch (QMessageBox::warning(this,
 			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
             tr("JACK is currently running.") + "\n\n" +
@@ -469,22 +488,26 @@ void qjackctlMainForm::startJack (void)
     }
 
     // Stabilize emerging server state...
-    updateServerState(m_bJackDetach ? QJACKCTL_ACTIVATING : QJACKCTL_STARTING);
+    updateServerState(QJACKCTL_ACTIVATING);
     ServerStateTextLabel->setPaletteForegroundColor(Qt::yellow);
-    StartPushButton->setEnabled(false);
+    StartToolButton->setEnabled(false);
 
     // Reset our timer counters...
     m_iStartDelay  = 0;
     m_iTimerDelay  = 0;
     m_iJackRefresh = 0;
 
-    // If we ain't to be the server master,  maybe we'll start 
+	// If we ain't to be the server master, maybe we'll start
 	// detached as client only (jackd server already running?)
     if (startJackClient(true)) {
-        StopPushButton->setEnabled(true);
+        StopToolButton->setEnabled(true);
         return;
     }
 
+    // Now we're sure it ain't detached.
+    updateServerState(QJACKCTL_STARTING);
+	m_bJackDetach = false;
+
     // Load primary/default server preset...
     if (!m_pSetup->loadPreset(m_preset, m_pSetup->sDefPreset)) {
         appendMessagesError(tr("Could not load preset \"%1\".\n\nRetrying with default.").arg(m_pSetup->sDefPreset));
@@ -496,9 +519,13 @@ void qjackctlMainForm::startJack (void)
         }
     }
 
-    // Do we have any startup script?...
-    if (m_pSetup->bStartupScript && !m_pSetup->sStartupScriptShell.isEmpty())
-        shellExecute(m_pSetup->sStartupScriptShell, tr("Startup script..."), tr("Startup script terminated"));
+	// Do we have any startup script?...
+	if (m_pSetup->bStartupScript
+		&& !m_pSetup->sStartupScriptShell.isEmpty()) {
+		shellExecute(m_pSetup->sStartupScriptShell,
+			tr("Startup script..."),
+			tr("Startup script terminated"));
+	}
 
     // OK. Let's build the startup process...
     m_pJack = new QProcess(this);
@@ -529,16 +556,22 @@ void qjackctlMainForm::startJack (void)
     }
 
     // Build process arguments...
-    for (QStringList::Iterator iter = args.begin(); iter != args.end(); ++iter)
+	bool bDummy     = (m_preset.sDriver == "dummy");
+	bool bOss       = (m_preset.sDriver == "oss");
+	bool bAlsa      = (m_preset.sDriver == "alsa");
+	bool bPortaudio = (m_preset.sDriver == "portaudio");
+	bool bCoreaudio = (m_preset.sDriver == "coreaudio");
+	bool bFreebob   = (m_preset.sDriver == "freebob");
+	for (QStringList::Iterator iter = args.begin(); iter != args.end(); ++iter)
 		m_pJack->addArgument(*iter);
     if (m_preset.bVerbose)
         m_pJack->addArgument("-v");
     if (m_preset.bRealtime) {
         m_pJack->addArgument("-R");
-        if (m_preset.iPriority > 0)
+        if (m_preset.iPriority > 0 && !bCoreaudio)
             m_pJack->addArgument("-P" + QString::number(m_preset.iPriority));
     }
-    if (m_preset.iPortMax > 0 && m_preset.iPortMax != 128)
+    if (m_preset.iPortMax > 0 && m_preset.iPortMax != 256)
         m_pJack->addArgument("-p" + QString::number(m_preset.iPortMax));
     if (m_preset.iTimeout > 0 && m_preset.iTimeout != 500)
         m_pJack->addArgument("-t" + QString::number(m_preset.iTimeout));
@@ -547,11 +580,6 @@ void qjackctlMainForm::startJack (void)
     else if (m_preset.bUnlockMem)
         m_pJack->addArgument("-u");
     m_pJack->addArgument("-d" + m_preset.sDriver);
-    bool bDummy     = (m_preset.sDriver == "dummy");
-    bool bOss       = (m_preset.sDriver == "oss");
-    bool bAlsa      = (m_preset.sDriver == "alsa");
-    bool bPortaudio = (m_preset.sDriver == "portaudio");
-	bool bCoreaudio = (m_preset.sDriver == "coreaudio");
     if (bAlsa && (m_preset.iAudio != QJACKCTL_DUPLEX ||
 		m_preset.sInDevice.isEmpty() || m_preset.sOutDevice.isEmpty())) {
 		QString sInterface = m_preset.sInterface;
@@ -561,13 +589,13 @@ void qjackctlMainForm::startJack (void)
 	}
     if (bPortaudio && m_preset.iChan > 0)
         m_pJack->addArgument("-c" + QString::number(m_preset.iChan));
-    if (bCoreaudio && !m_preset.sInterface.isEmpty())
-	    m_pJack->addArgument("-n" + m_preset.sInterface);
+    if ((bCoreaudio || bFreebob) && !m_preset.sInterface.isEmpty())
+	    m_pJack->addArgument("-d" + m_preset.sInterface);
     if (m_preset.iSampleRate > 0)
         m_pJack->addArgument("-r" + QString::number(m_preset.iSampleRate));
     if (m_preset.iFrames > 0)
         m_pJack->addArgument("-p" + QString::number(m_preset.iFrames));
-    if (bAlsa || bOss) {
+    if (bAlsa || bOss || bFreebob) {
         if (m_preset.iPeriods > 0)
             m_pJack->addArgument("-n" + QString::number(m_preset.iPeriods));
     }
@@ -599,12 +627,6 @@ void qjackctlMainForm::startJack (void)
 		if (m_preset.iOutChannels > 0 && m_preset.iAudio != QJACKCTL_CAPTURE)
 			m_pJack->addArgument("-o" + QString::number(m_preset.iOutChannels));
     }
-	else if (bCoreaudio) {
-		if (m_preset.iInChannels >= 0  && m_preset.iAudio != QJACKCTL_PLAYBACK)
-			m_pJack->addArgument("-i" + QString::number(m_preset.iInChannels));
-		if (m_preset.iOutChannels >= 0 && m_preset.iAudio != QJACKCTL_CAPTURE)
-			m_pJack->addArgument("-o" + QString::number(m_preset.iOutChannels));
-	}
     else if (bOss) {
         if (m_preset.bIgnoreHW)
             m_pJack->addArgument("-b");
@@ -623,6 +645,22 @@ void qjackctlMainForm::startJack (void)
         else if (m_preset.iOutChannels > 0)
             m_pJack->addArgument("-o" + QString::number(m_preset.iOutChannels));
     }
+	else if (bCoreaudio) {
+		if (m_preset.iInChannels >= 0  && m_preset.iAudio != QJACKCTL_PLAYBACK)
+			m_pJack->addArgument("-i" + QString::number(m_preset.iInChannels));
+		if (m_preset.iOutChannels >= 0 && m_preset.iAudio != QJACKCTL_CAPTURE)
+			m_pJack->addArgument("-o" + QString::number(m_preset.iOutChannels));
+	}
+	else if (bFreebob) {
+		if (m_preset.iInChannels >= 0  && m_preset.iAudio != QJACKCTL_PLAYBACK)
+			m_pJack->addArgument("-i" + QString::number(m_preset.iInChannels));
+		else
+			m_pJack->addArgument("-i0");
+		if (m_preset.iOutChannels >= 0 && m_preset.iAudio != QJACKCTL_CAPTURE)
+			m_pJack->addArgument("-o" + QString::number(m_preset.iOutChannels));
+		else
+			m_pJack->addArgument("-o0");
+	}
     if (bDummy && m_preset.iWait > 0 && m_preset.iWait != 21333)
         m_pJack->addArgument("-w" + QString::number(m_preset.iWait));
     if (bAlsa || bPortaudio) {
@@ -647,7 +685,7 @@ void qjackctlMainForm::startJack (void)
         if (m_preset.bHWMeter)
             m_pJack->addArgument("-M");
     }
-	if (bAlsa || bOss || bCoreaudio) {
+	if (bAlsa || bOss || bCoreaudio || bFreebob) {
 		if (m_preset.iInLatency > 0)
 			m_pJack->addArgument("-I" + QString::number(m_preset.iInLatency));
 		if (m_preset.iOutLatency > 0)
@@ -672,7 +710,7 @@ void qjackctlMainForm::startJack (void)
 
     // Sloppy boy fix: may the serve be stopped, just in case
     // the client will nerver make it...
-    StopPushButton->setEnabled(true);
+    StopToolButton->setEnabled(true);
 
     // Make sure all status(es) will be updated ASAP...
     m_iStatusRefresh += QJACKCTL_STATUS_CYCLE;
@@ -721,9 +759,13 @@ void qjackctlMainForm::stopJackServer (void)
     if (m_pJack && m_pJack->isRunning() && !m_bJackSurvive) {
         appendMessages(tr("JACK is stopping..."));
         updateServerState(QJACKCTL_STOPPING);
-        // Do we have any pre-shutdown script?...
-        if (m_pSetup->bShutdownScript && !m_pSetup->sShutdownScriptShell.isEmpty())
-            shellExecute(m_pSetup->sShutdownScriptShell, tr("Shutdown script..."), tr("Shutdown script terminated"));
+		// Do we have any pre-shutdown script?...
+		if (m_pSetup->bShutdownScript
+			&& !m_pSetup->sShutdownScriptShell.isEmpty()) {
+			shellExecute(m_pSetup->sShutdownScriptShell,
+				tr("Shutdown script..."),
+				tr("Shutdown script terminated"));
+		}
         // Now it's the time to real try stopping the server daemon...
         m_pJack->tryTerminate();
         // Give it some time to terminate gracefully and stabilize...
@@ -735,6 +777,16 @@ void qjackctlMainForm::stopJackServer (void)
 		return;
      }
 
+	// If we have a post-shutdown script enabled it must be called,
+	// despite we've not started the server before...
+	if (m_bJackDetach && !m_bJackSurvive
+		&& m_pSetup->bPostShutdownScript
+		&& !m_pSetup->sPostShutdownScriptShell.isEmpty()) {
+		shellExecute(m_pSetup->sPostShutdownScriptShell,
+			tr("Post-shutdown script..."),
+			tr("Post-shutdown script terminated"));
+	}
+
      // Do final processing anyway.
      processJackExit();
 }
@@ -793,9 +845,14 @@ void qjackctlMainForm::processJackExit (void)
         // Destroy it.
         delete m_pJack;
         m_pJack = NULL;
-        // Do we have any post-shutdown script?...
-        if (!m_bJackSurvive && m_pSetup->bPostShutdownScript && !m_pSetup->sPostShutdownScriptShell.isEmpty())
-            shellExecute(m_pSetup->sPostShutdownScriptShell, tr("Post-shutdown script..."), tr("Post-shutdown script terminated"));
+		// Do we have any post-shutdown script?...
+		// (this will be always called, despite we've started the server or not)
+		if (!m_bJackSurvive && m_pSetup->bPostShutdownScript
+			&& !m_pSetup->sPostShutdownScriptShell.isEmpty()) {
+			shellExecute(m_pSetup->sPostShutdownScriptShell,
+				tr("Post-shutdown script..."),
+				tr("Post-shutdown script terminated"));
+		}
     }
 
     // Stabilize final server state...
@@ -806,13 +863,13 @@ void qjackctlMainForm::processJackExit (void)
         iServerState = QJACKCTL_STOPPED;
     updateServerState(iServerState);
     ServerStateTextLabel->setPaletteForegroundColor(m_pJackClient == NULL ? Qt::darkYellow : Qt::yellow);
-    StartPushButton->setEnabled(m_pJackClient == NULL);
-    StopPushButton->setEnabled(m_pJackClient != NULL);
-    RewindPushButton->setEnabled(false);
-    BackwardPushButton->setEnabled(false);
-    PlayPushButton->setEnabled(false);
-    PausePushButton->setEnabled(false);
-    ForwardPushButton->setEnabled(false);
+    StartToolButton->setEnabled(m_pJackClient == NULL);
+    StopToolButton->setEnabled(m_pJackClient != NULL);
+    RewindToolButton->setEnabled(false);
+    BackwardToolButton->setEnabled(false);
+    PlayToolButton->setEnabled(false);
+    PauseToolButton->setEnabled(false);
+    ForwardToolButton->setEnabled(false);
 }
 
 
@@ -1069,6 +1126,71 @@ void qjackctlMainForm::updateAliases (void)
 }
 
 
+// Update the main form buttons display.
+void qjackctlMainForm::updateButtons (void)
+{
+	updateTitleStatus();
+
+	if (m_pSetup->bLeftButtons) {
+		StartToolButton->show();
+		StopToolButton->show();
+		MessagesToolButton->show();
+		StatusToolButton->show();
+		ConnectionsToolButton->show();
+		PatchbayToolButton->show();
+	} else {
+		StartToolButton->hide();
+		StopToolButton->hide();
+		MessagesToolButton->hide();
+		StatusToolButton->hide();
+		ConnectionsToolButton->hide();
+		PatchbayToolButton->hide();
+	}
+
+	if (m_pSetup->bRightButtons) {
+		QuitToolButton->show();
+		SetupToolButton->show();
+	} else {
+		QuitToolButton->hide();
+		SetupToolButton->hide();
+	}
+
+	if (m_pSetup->bRightButtons &&
+		(m_pSetup->bLeftButtons || m_pSetup->bTransportButtons)) {
+		AboutToolButton->show();
+	} else {
+		AboutToolButton->hide();
+	}
+
+	if (m_pSetup->bLeftButtons || m_pSetup->bTransportButtons) {
+		RewindToolButton->show();
+		BackwardToolButton->show();
+		PlayToolButton->show();
+		PauseToolButton->show();
+		ForwardToolButton->show();
+	} else {
+		RewindToolButton->hide();
+		BackwardToolButton->hide();
+		PlayToolButton->hide();
+		PauseToolButton->hide();
+		ForwardToolButton->hide();
+	}
+
+	bool bTextLabels = m_pSetup->bTextLabels;
+	StartToolButton->setUsesTextLabel(bTextLabels);
+	StopToolButton->setUsesTextLabel(bTextLabels);
+	MessagesToolButton->setUsesTextLabel(bTextLabels);
+	StatusToolButton->setUsesTextLabel(bTextLabels);
+	ConnectionsToolButton->setUsesTextLabel(bTextLabels);
+	PatchbayToolButton->setUsesTextLabel(bTextLabels);
+	QuitToolButton->setUsesTextLabel(bTextLabels);
+	SetupToolButton->setUsesTextLabel(bTextLabels);
+	AboutToolButton->setUsesTextLabel(bTextLabels);
+
+	adjustSize();
+}
+
+
 // Force update of active patchbay definition profile, if applicable.
 bool qjackctlMainForm::isActivePatchbay ( const QString& sPatchbayPath )
 {
@@ -1134,10 +1256,10 @@ void qjackctlMainForm::setRecentPatchbays ( const QStringList& patchbays )
 // Stabilize current form toggle buttons that may be astray.
 void qjackctlMainForm::stabilizeForm (void)
 {
-    MessagesPushButton->setOn(m_pMessagesForm && m_pMessagesForm->isVisible());
-    StatusPushButton->setOn(m_pStatusForm && m_pStatusForm->isVisible());
-    ConnectionsPushButton->setOn(m_pConnectionsForm && m_pConnectionsForm->isVisible());
-    PatchbayPushButton->setOn(m_pPatchbayForm && m_pPatchbayForm->isVisible());
+    MessagesToolButton->setOn(m_pMessagesForm && m_pMessagesForm->isVisible());
+    StatusToolButton->setOn(m_pStatusForm && m_pStatusForm->isVisible());
+    ConnectionsToolButton->setOn(m_pConnectionsForm && m_pConnectionsForm->isVisible());
+    PatchbayToolButton->setOn(m_pPatchbayForm && m_pPatchbayForm->isVisible());
 }
 
 
@@ -1587,8 +1709,8 @@ bool qjackctlMainForm::startJackClient ( bool bDetach )
     QString sClientName = "qjackctl-" + QString::number((int) ::getpid());
     m_pJackClient = jack_client_new(sClientName.latin1());
     if (m_pJackClient == NULL) {
-        if (!bDetach) {
-            appendMessagesError(
+		if (!bDetach) {
+			appendMessagesError(
 				tr("Could not connect to JACK server as client.\n\n"
 				"Please check the messages window for more info."));
 		}
@@ -1633,7 +1755,7 @@ bool qjackctlMainForm::startJackClient ( bool bDetach )
     if (!bDetach)
         resetXrunStats();
 	else // We'll flag that we've been detached!
-    	m_bJackDetach = true;
+		m_bJackDetach = true;
 
     // Activate us as a client...
     jack_activate(m_pJackClient);
@@ -1653,25 +1775,31 @@ bool qjackctlMainForm::startJackClient ( bool bDetach )
 
     // Whether we've started detached, just change active status.
     updateServerState(m_bJackDetach ? QJACKCTL_ACTIVE : QJACKCTL_STARTED);
-    StopPushButton->setEnabled(true);
+    StopToolButton->setEnabled(true);
 
     // Log success here.
     appendMessages(tr("Client activated."));
 
-    // Do we have any post-startup scripting?...
-    // (only if we're not a detached client)
-    if (!bDetach && !m_bJackDetach) {
-        if (m_pSetup->bPostStartupScript && !m_pSetup->sPostStartupScriptShell.isEmpty())
-            shellExecute(m_pSetup->sPostStartupScriptShell, tr("Post-startup script..."), tr("Post-startup script terminated"));
-    }
+	// Do we have any post-startup scripting?...
+	// (only if we're not a detached client)
+	if (!bDetach && !m_bJackDetach) {
+		if (m_pSetup->bPostStartupScript
+			&& !m_pSetup->sPostStartupScriptShell.isEmpty()) {
+			shellExecute(m_pSetup->sPostStartupScriptShell,
+				tr("Post-startup script..."),
+				tr("Post-startup script terminated"));
+		}
+	}
 
-    // Have we an initial command-line to start away?
-    if (!m_pSetup->sCmdLine.isEmpty()) {
-        // Run it dettached...
-        shellExecute(m_pSetup->sCmdLine, tr("Command line argument..."), tr("Command line argument started"));
-        // And reset it forever more...
-        m_pSetup->sCmdLine = QString::null;
-    }
+	// Have we an initial command-line to start away?
+	if (!m_pSetup->sCmdLine.isEmpty()) {
+		// Run it dettached...
+		shellExecute(m_pSetup->sCmdLine,
+			tr("Command line argument..."),
+			tr("Command line argument started"));
+		// And reset it forever more...
+		m_pSetup->sCmdLine = QString::null;
+	}
 
     // OK, we're at it!
     return true;
@@ -1875,6 +2003,10 @@ void qjackctlMainForm::showSetupForm (void)
         bool    bOldBezierLines         = m_pSetup->bBezierLines;
         bool    bOldAliasesEnabled      = m_pSetup->bAliasesEnabled;
         bool    bOldAliasesEditing      = m_pSetup->bAliasesEditing;
+        bool    bOldLeftButtons         = m_pSetup->bLeftButtons;
+        bool    bOldRightButtons        = m_pSetup->bRightButtons;
+        bool    bOldTransportButtons    = m_pSetup->bTransportButtons;
+        bool    bOldTextLabels          = m_pSetup->bTextLabels;
         // Load the current setup settings.
         pSetupForm->setup(m_pSetup);
         // Show the setup dialog...
@@ -1914,6 +2046,15 @@ void qjackctlMainForm::showSetupForm (void)
 				( bOldAliasesEditing && !m_pSetup->bAliasesEditing) ||
 				(!bOldAliasesEditing &&  m_pSetup->bAliasesEditing))
 				updateAliases();
+            if (( bOldLeftButtons  && !m_pSetup->bLeftButtons)  ||
+                (!bOldLeftButtons  &&  m_pSetup->bLeftButtons)  ||
+                ( bOldRightButtons && !m_pSetup->bRightButtons) ||
+                (!bOldRightButtons &&  m_pSetup->bRightButtons) ||
+                ( bOldTransportButtons && !m_pSetup->bTransportButtons) ||
+                (!bOldTransportButtons &&  m_pSetup->bTransportButtons) ||
+                ( bOldTextLabels && !m_pSetup->bTextLabels) ||
+                (!bOldTextLabels &&  m_pSetup->bTextLabels))
+                updateButtons();
             // Warn if something will be only effective on next run.
             if (( bOldStdoutCapture && !m_pSetup->bStdoutCapture) ||
                 (!bOldStdoutCapture &&  m_pSetup->bStdoutCapture) ||
@@ -1970,7 +2111,7 @@ void qjackctlMainForm::transportBackward (void)
 		if (m_fSkipAccel < 1.1) 
 			appendMessages(tr("Transport backward."));
 		// Take care of backward acceleration...
-		if (BackwardPushButton->isDown() && m_fSkipAccel < 60.0)
+		if (BackwardToolButton->isDown() && m_fSkipAccel < 60.0)
 			m_fSkipAccel *= 1.1;
 		// Make sure all status(es) will be updated ASAP...
 		m_iStatusRefresh += QJACKCTL_STATUS_CYCLE;
@@ -2023,7 +2164,7 @@ void qjackctlMainForm::transportForward (void)
 		if (m_fSkipAccel < 1.1) 
 			appendMessages(tr("Transport forward."));
 		// Take care of forward acceleration...
-		if (ForwardPushButton->isDown() && m_fSkipAccel < 60.0)
+		if (ForwardToolButton->isDown() && m_fSkipAccel < 60.0)
 			m_fSkipAccel *= 1.1;
 		// Make sure all status(es) will be updated ASAP...
 		m_iStatusRefresh += QJACKCTL_STATUS_CYCLE;
@@ -2093,20 +2234,20 @@ void qjackctlMainForm::refreshStatus (void)
                 break;
             }
             updateStatusItem(STATUS_TRANSPORT_STATE, sText);
-			RewindPushButton->setEnabled(tpos.frame > 0);
-			BackwardPushButton->setEnabled(tpos.frame > 0);
-			PlayPushButton->setEnabled(tstate == JackTransportStopped);
-			PausePushButton->setEnabled(bPlaying);
-			ForwardPushButton->setEnabled(true);
-			if (!BackwardPushButton->isDown() && !ForwardPushButton->isDown())
+			RewindToolButton->setEnabled(tpos.frame > 0);
+			BackwardToolButton->setEnabled(tpos.frame > 0);
+			PlayToolButton->setEnabled(tstate == JackTransportStopped);
+			PauseToolButton->setEnabled(bPlaying);
+			ForwardToolButton->setEnabled(true);
+			if (!BackwardToolButton->isDown() && !ForwardToolButton->isDown())
 				m_fSkipAccel = 1.0;
 #else
             updateStatusItem(STATUS_TRANSPORT_STATE, n);
-			RewindPushButton->setEnabled(false);
-			BackwardPushButton->setEnabled(false);
-			PlayPushButton->setEnabled(false);
-			PausePushButton->setEnabled(false);
-			ForwardPushButton->setEnabled(false);
+			RewindToolButton->setEnabled(false);
+			BackwardToolButton->setEnabled(false);
+			PlayToolButton->setEnabled(false);
+			PauseToolButton->setEnabled(false);
+			ForwardToolButton->setEnabled(false);
             updateStatusItem(STATUS_TRANSPORT_TIME, m_sTimeDashes);
             updateStatusItem(STATUS_TRANSPORT_BBT, b);
             updateStatusItem(STATUS_TRANSPORT_BPM, n);
@@ -2139,11 +2280,11 @@ void qjackctlMainForm::refreshStatus (void)
         updateStatusItem(STATUS_TRANSPORT_TIME, m_sTimeDashes);
         updateStatusItem(STATUS_TRANSPORT_BBT, b);
         updateStatusItem(STATUS_TRANSPORT_BPM, n);
-		RewindPushButton->setEnabled(false);
-		BackwardPushButton->setEnabled(false);
-		PlayPushButton->setEnabled(false);
-		PausePushButton->setEnabled(false);
-		ForwardPushButton->setEnabled(false);
+		RewindToolButton->setEnabled(false);
+		BackwardToolButton->setEnabled(false);
+		PlayToolButton->setEnabled(false);
+		PauseToolButton->setEnabled(false);
+		ForwardToolButton->setEnabled(false);
     }
 
     // Elapsed times should be rigorous...
@@ -2196,10 +2337,17 @@ void qjackctlMainForm::updateStatusItem( int iStatusItem, const QString& sText )
 // Main window caption title and system tray icon and tooltip update.
 void qjackctlMainForm::updateTitleStatus (void)
 {
-    QString sTitle = QJACKCTL_SUBTITLE1 " ";
+    QString sTitle;
 
-    if (m_pSetup)
-        sTitle += "[" + m_pSetup->sDefPreset + "] ";
+	if (!m_pSetup->bLeftButtons  ||
+		!m_pSetup->bRightButtons ||
+		!m_pSetup->bTextLabels) {
+		sTitle = QJACKCTL_SUBTITLE0;
+	} else {
+		sTitle = QJACKCTL_SUBTITLE1;
+	}
+
+    sTitle += " [" + m_pSetup->sDefPreset + "] ";
 
     QString sState;
     QString sDots = ".";
@@ -2350,7 +2498,7 @@ void qjackctlMainForm::systemTrayContextMenu ( const QPoint& pos )
     m_pPresetsMenu->setItemParameter(iItemID, -1);
     QObject::connect(m_pPresetsMenu, SIGNAL(activated(int)), this, SLOT(activatePresetsMenu(int)));
     // Add presets menu to the main context menu...
-    pContextMenu->insertItem(tr("Presets"), m_pPresetsMenu);
+    pContextMenu->insertItem(tr("&Presets"), m_pPresetsMenu);
     pContextMenu->insertSeparator();
 
     iItemID = pContextMenu->insertItem(QIconSet(QPixmap::fromMimeSource("messages1.png")),
@@ -2367,10 +2515,37 @@ void qjackctlMainForm::systemTrayContextMenu ( const QPoint& pos )
     pContextMenu->setItemChecked(iItemID, m_pPatchbayForm && m_pPatchbayForm->isVisible());
     pContextMenu->insertSeparator();
 
+	QPopupMenu *pTransportMenu = new QPopupMenu(this);
+	iItemID = pTransportMenu->insertItem(
+		QIconSet(QPixmap::fromMimeSource("rewind1.png")),
+		tr("&Rewind"), this, SLOT(transportRewind()));
+	pTransportMenu->setItemEnabled(iItemID, RewindToolButton->isEnabled());
+//	iItemID = pTransportMenu->insertItem(
+//		QIconSet(QPixmap::fromMimeSource("backward1.png")),
+//		tr("&Backward"), this, SLOT(transportBackward()));
+//	pTransportMenu->setItemEnabled(iItemID, BackwardToolButton->isEnabled());
+	iItemID = pTransportMenu->insertItem(
+		QIconSet(QPixmap::fromMimeSource("play1.png")),
+		tr("&Play"), this, SLOT(transportStart()));
+	pTransportMenu->setItemEnabled(iItemID, PlayToolButton->isEnabled());
+	iItemID = pTransportMenu->insertItem(
+		QIconSet(QPixmap::fromMimeSource("pause1.png")),
+		tr("Pa&use"), this, SLOT(transportStop()));
+	pTransportMenu->setItemEnabled(iItemID, PauseToolButton->isEnabled());
+//	iItemID = pTransportMenu->insertItem(
+//		QIconSet(QPixmap::fromMimeSource("forward1.png")),
+//		tr("&Forward"), this, SLOT(transportForward()));
+//	pTransportMenu->setItemEnabled(iItemID, ForwardToolButton->isEnabled());
+	pContextMenu->insertItem(tr("&Transport"), pTransportMenu);
+	pContextMenu->insertSeparator();
+
     pContextMenu->insertItem(QIconSet(QPixmap::fromMimeSource("setup1.png")),
         tr("S&etup..."), this, SLOT(showSetupForm()));
-//  pContextMenu->insertItem(QIconSet(QPixmap::fromMimeSource("about1.png")),
-//      tr("Ab&out..."), this, SLOT(showAboutForm()));
+
+	if (!m_pSetup->bRightButtons || !m_pSetup->bTransportButtons) {
+		pContextMenu->insertItem(QIconSet(QPixmap::fromMimeSource("about1.png")),
+			tr("Ab&out..."), this, SLOT(showAboutForm()));
+	}
     pContextMenu->insertSeparator();
 
     pContextMenu->insertItem(QIconSet(QPixmap::fromMimeSource("quit1.png")),
@@ -2378,10 +2553,14 @@ void qjackctlMainForm::systemTrayContextMenu ( const QPoint& pos )
 
     pContextMenu->exec(pos);
 
-    delete pContextMenu;
-
     delete m_pPresetsMenu;
     m_pPresetsMenu = NULL;
+
+	if (pTransportMenu)
+		delete pTransportMenu;
+
+    delete pContextMenu;
+
 }
 
 
