@@ -1,7 +1,7 @@
 // qjackctlSetup.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2005, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2006, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -13,9 +13,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 *****************************************************************************/
 
@@ -53,8 +53,8 @@ qjackctlSetup::qjackctlSetup (void)
     sPostStartupScriptShell  = m_settings.readEntry("/PostStartupScriptShell", QString::null);
     bShutdownScript          = m_settings.readBoolEntry("/ShutdownScript", false);
     sShutdownScriptShell     = m_settings.readEntry("/ShutdownScriptShell", QString::null);
-    bPostShutdownScript      = m_settings.readBoolEntry("/PostShutdownScript", false);
-    sPostShutdownScriptShell = m_settings.readEntry("/PostShutdownScriptShell", QString::null);
+    bPostShutdownScript      = m_settings.readBoolEntry("/PostShutdownScript", true);
+    sPostShutdownScriptShell = m_settings.readEntry("/PostShutdownScriptShell", "killall jackd");
     bStdoutCapture           = m_settings.readBoolEntry("/StdoutCapture", true);
     sXrunRegex               = m_settings.readEntry("/XrunRegex", "xrun of at least ([0-9|\\.]+) msecs");
     bXrunIgnoreFirst         = m_settings.readBoolEntry("/XrunIgnoreFirst", false);
@@ -88,6 +88,10 @@ qjackctlSetup::qjackctlSetup (void)
     bQueryShutdown           = m_settings.readBoolEntry("/QueryShutdown", true);
     bAliasesEnabled          = m_settings.readBoolEntry("/AliasesEnabled", false);
     bAliasesEditing          = m_settings.readBoolEntry("/AliasesEditing", false);
+    bLeftButtons             = m_settings.readBoolEntry("/LeftButtons", true);
+    bRightButtons            = m_settings.readBoolEntry("/RightButtons", true);
+    bTransportButtons        = m_settings.readBoolEntry("/TransportButtons", true);
+    bTextLabels              = m_settings.readBoolEntry("/TextLabels", true);
     m_settings.endGroup();
 
     m_settings.beginGroup("/Defaults");
@@ -167,6 +171,10 @@ qjackctlSetup::~qjackctlSetup (void)
     m_settings.writeEntry("/QueryShutdown",           bQueryShutdown);
     m_settings.writeEntry("/AliasesEnabled",          bAliasesEnabled);
     m_settings.writeEntry("/AliasesEditing",          bAliasesEditing);
+    m_settings.writeEntry("/LeftButtons",             bLeftButtons);
+    m_settings.writeEntry("/RightButtons",            bRightButtons);
+    m_settings.writeEntry("/TransportButtons",        bTransportButtons);
+    m_settings.writeEntry("/TextLabels",              bTextLabels);
     m_settings.endGroup();
 
     m_settings.beginGroup("/Defaults");
@@ -290,7 +298,7 @@ bool qjackctlSetup::loadPreset ( qjackctlPreset& preset, const QString& sPreset
     preset.iOutLatency  = m_settings.readNumEntry("/OutLatency", 0);
     preset.iStartDelay  = m_settings.readNumEntry("/StartDelay", 2);
     preset.bVerbose     = m_settings.readBoolEntry("/Verbose", false);
-    preset.iPortMax     = m_settings.readNumEntry("/PortMax", 128);
+    preset.iPortMax     = m_settings.readNumEntry("/PortMax", 256);
     m_settings.endGroup();
 
     return true;
